pub struct DetectConfigDriftInput {
pub environment_id: String,
}Fields
environment_id: StringTrait Implementations
Sourceimpl Debug for DetectConfigDriftInput
impl Debug for DetectConfigDriftInput
Sourceimpl<'de> Deserialize<'de> for DetectConfigDriftInput
impl<'de> Deserialize<'de> for DetectConfigDriftInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DetectConfigDriftInput
impl JsonSchema for DetectConfigDriftInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DetectConfigDriftInput
impl RefUnwindSafe for DetectConfigDriftInput
impl Send for DetectConfigDriftInput
impl Sync for DetectConfigDriftInput
impl Unpin for DetectConfigDriftInput
impl UnsafeUnpin for DetectConfigDriftInput
impl UnwindSafe for DetectConfigDriftInput