pub struct GetDeployHistoryInput {
pub environment_id: String,
pub limit: Option<usize>,
}Fields
environment_id: Stringlimit: Option<usize>Trait Implementations
Sourceimpl Debug for GetDeployHistoryInput
impl Debug for GetDeployHistoryInput
Sourceimpl<'de> Deserialize<'de> for GetDeployHistoryInput
impl<'de> Deserialize<'de> for GetDeployHistoryInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GetDeployHistoryInput
impl JsonSchema for GetDeployHistoryInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for GetDeployHistoryInput
impl RefUnwindSafe for GetDeployHistoryInput
impl Send for GetDeployHistoryInput
impl Sync for GetDeployHistoryInput
impl Unpin for GetDeployHistoryInput
impl UnsafeUnpin for GetDeployHistoryInput
impl UnwindSafe for GetDeployHistoryInput