pub struct GetEnvironmentInput {
pub environment_id: String,
}Fields
environment_id: StringTrait Implementations
Sourceimpl Debug for GetEnvironmentInput
impl Debug for GetEnvironmentInput
Sourceimpl<'de> Deserialize<'de> for GetEnvironmentInput
impl<'de> Deserialize<'de> for GetEnvironmentInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GetEnvironmentInput
impl JsonSchema for GetEnvironmentInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for GetEnvironmentInput
impl RefUnwindSafe for GetEnvironmentInput
impl Send for GetEnvironmentInput
impl Sync for GetEnvironmentInput
impl Unpin for GetEnvironmentInput
impl UnsafeUnpin for GetEnvironmentInput
impl UnwindSafe for GetEnvironmentInput