pub struct ScaleWorkerPoolInput {
pub environment_id: String,
pub pool_type: PoolType,
pub desired_capacity: u32,
pub reason: Option<String>,
}Fields
environment_id: Stringpool_type: PoolTypedesired_capacity: u32reason: Option<String>Trait Implementations
Sourceimpl Debug for ScaleWorkerPoolInput
impl Debug for ScaleWorkerPoolInput
Sourceimpl<'de> Deserialize<'de> for ScaleWorkerPoolInput
impl<'de> Deserialize<'de> for ScaleWorkerPoolInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ScaleWorkerPoolInput
impl JsonSchema for ScaleWorkerPoolInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ScaleWorkerPoolInput
impl RefUnwindSafe for ScaleWorkerPoolInput
impl Send for ScaleWorkerPoolInput
impl Sync for ScaleWorkerPoolInput
impl Unpin for ScaleWorkerPoolInput
impl UnsafeUnpin for ScaleWorkerPoolInput
impl UnwindSafe for ScaleWorkerPoolInput