pub struct SyncConfigInput {
pub environment_id: String,
pub config: Option<Value>,
pub mode: Option<String>,
}Fields
environment_id: Stringconfig: Option<Value>mode: Option<String>Trait Implementations
Sourceimpl Debug for SyncConfigInput
impl Debug for SyncConfigInput
Sourceimpl<'de> Deserialize<'de> for SyncConfigInput
impl<'de> Deserialize<'de> for SyncConfigInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SyncConfigInput
impl JsonSchema for SyncConfigInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SyncConfigInput
impl RefUnwindSafe for SyncConfigInput
impl Send for SyncConfigInput
impl Sync for SyncConfigInput
impl Unpin for SyncConfigInput
impl UnsafeUnpin for SyncConfigInput
impl UnwindSafe for SyncConfigInput