pub struct ValidateEnvironmentInput {
pub environment_id: String,
pub scope: Option<String>,
}Fields
environment_id: Stringscope: Option<String>Trait Implementations
Sourceimpl Debug for ValidateEnvironmentInput
impl Debug for ValidateEnvironmentInput
Sourceimpl<'de> Deserialize<'de> for ValidateEnvironmentInput
impl<'de> Deserialize<'de> for ValidateEnvironmentInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ValidateEnvironmentInput
impl JsonSchema for ValidateEnvironmentInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ValidateEnvironmentInput
impl RefUnwindSafe for ValidateEnvironmentInput
impl Send for ValidateEnvironmentInput
impl Sync for ValidateEnvironmentInput
impl Unpin for ValidateEnvironmentInput
impl UnsafeUnpin for ValidateEnvironmentInput
impl UnwindSafe for ValidateEnvironmentInput